==> alwaysai-2.3.4.tgz: package/src/components/device/generate-production-device.ts <==
import { CliTerseError } from '@alwaysai/alwayscli';
import { join } from 'path';
import { PLEASE_REPORT_THIS_ERROR_MESSAGE } from '../../constants';
import { checkUserIsLoggedInComponent } from '../user';
import { echo, JsSpawner, logger, runWithSpinner } from '../../util';
import { requirePaidPlan } from '../../core/project';
import { CliAuthenticationClient, AddedDevice, addDevice } from '../../infrastructure';
import { writeOrValidateDeviceCfgFile } from '../../core/device/write-or-validate-device-cfg-file';
import { writeCertificate, writeTokens } from '../../core/device';

export async function generateProductionDeviceFunc(props: {
  name: string;
  description?: string;
}) {
  const { name, description } = props;
  await checkUserIsLoggedInComponent({ yes: false });
  await requirePaidPlan();

  const { username } = await CliAuthenticationClient().getInfo();
  const deviceToAdd = {
    owner: username,
    friendly_name: name,
    host_name: '',
    device_user_name: '',
    description: description || '',
    hardware_ids: '',
    device_hash: '',
    iotKeys: '',
  };
  try {
    const response: AddedDevice = await generateDevice(deviceToAdd);
    const outDir = join(process.cwd(), response.deviceUUID);
    const cfgDir = join(outDir, '.config', 'alwaysai');
    await runWithSpinner(
      async () => {
        const tokenSpawner = JsSpawner({ path: cfgDir });
        await writeTokens({
          spawner: tokenSpawner,
          tokens: {
            deviceId: response.deviceUUID,
            accessToken: response.accessToken,
            refreshToken: response.refreshToken,
            idToken: response.idToken,
          },
        });
        await writeOrValidateDeviceCfgFile({
          spawner: tokenSpawner,
          deviceUuid: response.deviceUUID,
        });

        const certSpawner = JsSpawner({ path: join(cfgDir, 'certificates') });
        await writeCertificate({
          spawner: certSpawner,
          certificate: response.iotKeys.certificatePem,
          privateKey: response.iotKeys.keyPair.PrivateKey,
          rootCa: response.iotKeys.rootCA,
        });
      },
      [],
      `Write device credentials to ${outDir}`,
    );
    echo(`Created ${name}: device ID=${response.deviceUUID}`);
    return response.deviceUUID;
  } catch (error) {
    logger.error(error);
    throw new CliTerseError(
      `There was an error with creating the device. ${PLEASE_REPORT_THIS_ERROR_MESSAGE}`,
    );
  }
}

async function generateDevice(deviceToAdd) {
  let response;
  await runWithSpinner(
    async () => {
      response = await addDevice(deviceToAdd, 'production');
    },
    [],
    'Create new production device',
  );
  return response;
}

==> alwaysai-2.4.0.tgz: package/src/components/device/generate-production-device.ts <==
import { CliTerseError } from '@alwaysai/alwayscli';
import { join } from 'path';
import { PLEASE_REPORT_THIS_ERROR_MESSAGE } from '../../constants';
import { checkUserIsLoggedInComponent } from '../user';
import { echo, JsSpawner, logger, runWithSpinner } from '../../util';
import { requirePaidPlan } from '../../core/project';
import { CliAuthenticationClient, AddedDevice, addDevice } from '../../infrastructure';
import { writeDeviceCfgFile } from '../../core/device/write-or-validate-device-cfg-file';
import { writeCertificate, writeTokens } from '../../core/device';

export async function generateProductionDeviceFunc(props: {
  name: string;
  description?: string;
}) {
  const { name, description } = props;
  await checkUserIsLoggedInComponent({ yes: false });
  await requirePaidPlan();

  const { username } = await CliAuthenticationClient().getInfo();
  const deviceToAdd = {
    owner: username,
    friendly_name: name,
    host_name: '',
    device_user_name: '',
    description: description || '',
    hardware_ids: '',
    device_hash: '',
    iotKeys: '',
  };
  try {
    const response: AddedDevice = await generateDevice(deviceToAdd);
    const outDir = join(process.cwd(), response.deviceUUID);
    const cfgDir = join(outDir, '.config', 'alwaysai');
    await runWithSpinner(
      async () => {
        const tokenSpawner = JsSpawner({ path: cfgDir });
        await writeTokens({
          spawner: tokenSpawner,
          tokens: {
            deviceId: response.deviceUUID,
            accessToken: response.accessToken,
            refreshToken: response.refreshToken,
            idToken: response.idToken,
          },
        });
        await writeDeviceCfgFile({
          spawner: tokenSpawner,
          deviceUuid: response.deviceUUID,
        });

        const certSpawner = JsSpawner({ path: join(cfgDir, 'certificates') });
        await writeCertificate({
          spawner: certSpawner,
          certificate: response.iotKeys.certificatePem,
          privateKey: response.iotKeys.keyPair.PrivateKey,
          rootCa: response.iotKeys.rootCA,
        });
      },
      [],
      `Write device credentials to ${outDir}`,
    );
    echo(`Created ${name}: device ID=${response.deviceUUID}`);
    return response.deviceUUID;
  } catch (error) {
    logger.error(error);
    throw new CliTerseError(
      `There was an error with creating the device. ${PLEASE_REPORT_THIS_ERROR_MESSAGE}`,
    );
  }
}

async function generateDevice(deviceToAdd) {
  let response;
  await runWithSpinner(
    async () => {
      response = await addDevice(deviceToAdd, 'production');
    },
    [],
    'Create new production device',
  );
  return response;
}
